@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_internal_defs_c.h
  * @brief		iris unit test def t@C
@@ -8,23 +8,21 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012 Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 #ifndef INCG_IRIS_iutest_defs_c_H_2EF67DBB_93CC_4c5a_BCB6_556CD9265270_
 #define INCG_IRIS_iutest_defs_c_H_2EF67DBB_93CC_4c5a_BCB6_556CD9265270_
 
-//======================================================================
-// include
+/* include ===========================================================*/
 #include "iutest_compiler_c.h"
 #include "iutest_pp_c.h"
 #include "iutest_libc_c.h"
 
-//======================================================================
-// define
+/* define ============================================================*/
 
 /**
  * @brief	B else ̌x}
@@ -35,15 +33,15 @@
 #  define IUTEST_AMBIGUOUS_ELSE_BLOCKER_	switch(iuAlwaysZero()) case 0: default:
 #endif
 
-// for C
+/* for C */
 #if		defined(_MSC_VER)
 #  pragma section(".CRT$XCU", read)
 #  define IUTEST_C_DECL_INITIALIZATION_SECTION(name)	\
-	static void	__cdecl name(void);						\
+	void	__cdecl name(void);							\
 	static __declspec(allocate(".CRT$XCU")) void (__cdecl * IUTEST_PP_CAT(pfn,name))(void) = name;	\
-	static void	__cdecl name(void)
+	void	__cdecl name(void)
 
-// /OPT:REF ō폜Ȃ߂̑΍
+/* /OPT:REF ō폜Ȃ߂̑΍ */
 #  define IUTEST_C_DECL_INITIALIZATION_SECTION_BEGIN(name)	\
 	IUTEST_C_DECL_INITIALIZATION_SECTION(name) {			\
 		(void)IUTEST_PP_CAT(pfn,name);
@@ -53,8 +51,8 @@
 
 #elif	defined(__GNUC__)
 #  define IUTEST_C_DECL_INITIALIZATION_SECTION(name)		\
-	static void	name(void) __attribute__((constructor));	\
-	static void	name(void)
+	void	name(void) __attribute__((constructor));		\
+	void	name(void)
 
 #  define IUTEST_C_DECL_INITIALIZATION_SECTION_BEGIN(name)	\
 	IUTEST_C_DECL_INITIALIZATION_SECTION(name) {			\
@@ -62,8 +60,24 @@
 #  define IUTEST_C_DECL_INITIALIZATION_SECTION_END()		\
 	}
 
+#else
+#  define IUTEST_C_DECL_INITIALIZATION_SECTION_BEGIN(name)	\
+	void name(void) {
+
+#  define IUTEST_C_DECL_INITIALIZATION_SECTION_END()		\
+	}
 #endif
 
+/* ֐̖IĂяo */
+#  define IUTEST_C_CALL_INITIALIZATION_SECTION(name) do {	\
+		IUTEST_PRAGMA_MSC_WARN_PUSH()						\
+		IUTEST_PRAGMA_MSC_WARN_DISABLE(4210)				\
+		extern void name(void);								\
+		name();												\
+		IUTEST_PRAGMA_MSC_WARN_POP()						\
+	} while(iuAlwaysZero())
+
+
 
 #ifndef IUTEST_C_BREAK
 #  if	defined(_MSC_VER)
@@ -74,7 +88,7 @@
 #    define IUTEST_C_BREAK()	do { __breakpoint(0xF02C); } while(iuAlwaysZero())
 #  else
 #    define IUTEST_C_BREAK()	*(volatile int*)(NULL) = 1;
-//#    define IUTEST_BREAK()	(void)0
+/*#    define IUTEST_BREAK()	(void)0*/
 #  endif
 #endif
 
@@ -84,59 +98,68 @@
 */
 
 #define iuTestHelper_AddList(list_type, top, elem) do {		\
-		if( (top) == NULL ) { top = elem; }					\
+		if( (top) == NULL ) { (top) = (elem); }				\
 		else {												\
-			list_type* prev = (top);						\
-			list_type* curr = (top)->next;					\
+			list_type *prev = (top);						\
+			list_type *curr = (top)->next;					\
 			while( curr != NULL ) {							\
 				prev = curr; curr = curr->next;				\
 			}												\
-			prev->next = elem;								\
+			prev->next = (elem);							\
+		}													\
+	} while(iuAlwaysZero())
+
+#define iuTestHelper_FindList(list_type, top, elem, ret) do {	\
+		list_type *curr = (top);							\
+		(ret) = FALSE;										\
+		while( curr != NULL ) {								\
+			if( curr == elem ) { (ret) = TRUE;	break; }	\
+			curr = curr->next;								\
 		}													\
 	} while(iuAlwaysZero())
 
 #define iuTestHelper_CountList(counter, list_type, top)	do {	\
-		list_type* curr = top;									\
-		counter = 0;											\
+		list_type *curr = (top);								\
+		(counter) = 0;											\
 		while(curr != NULL) {									\
-			++counter;											\
+			++(counter);										\
 			curr = curr->next;									\
 		}														\
 	} while(iuAlwaysZero())
 
 #define iuTestHelper_ListGetAt(list_type, top, at, ret)	do {	\
-		list_type* curr = top;									\
+		list_type *curr = (top);								\
 		unsigned int i=0;										\
 		for(i=0; i < (at); ++i ) {								\
 			curr = curr->next;									\
 		}														\
-		ret = curr;												\
+		(ret) = curr;											\
 	} while(iuAlwaysZero())
 
 #define iuTestHelper_ShuffleList(list_type, gen, count, top)	do {	\
-		list_type* curr = top;											\
-		list_type* pre = NULL;											\
+		list_type *curr = top;											\
+		list_type *pre = NULL;											\
 		unsigned int i=2, n=count;										\
 		for( i=2; i<n; ++i ) {											\
 			list_type *rhs_pre=NULL, *rhs=NULL;							\
-			unsigned int pos = gen % i;									\
+			unsigned int pos = (unsigned int)(gen % i);					\
 			iuTestHelper_ListGetAt(list_type, top, pos, rhs);			\
-			if( pos != 0 ) iuTestHelper_ListGetAt(list_type, top, pos-1, rhs_pre);	\
+			if( pos != 0 ) iuTestHelper_ListGetAt(list_type, top, pos-1u, rhs_pre);	\
 			if( curr != rhs ) {											\
 				if( pre == NULL ) {										\
-					list_type* tmp = rhs->next;							\
+					list_type *tmp = rhs->next;							\
 					rhs->next = curr->next; curr->next = tmp;			\
 					if( rhs_pre == curr ) rhs->next = curr;				\
 					else rhs_pre->next = curr;							\
 					top = rhs;											\
 				} else if( rhs_pre == NULL ) {							\
-					list_type* tmp = rhs->next;							\
+					list_type *tmp = rhs->next;							\
 					rhs->next = curr->next; curr->next = tmp;			\
 					if( pre == rhs ) curr->next = rhs;					\
 					else pre->next = rhs;								\
 					top = curr;											\
 				} else {												\
-					list_type* tmp = rhs->next;							\
+					list_type *tmp = rhs->next;							\
 					rhs->next = curr->next; curr->next = tmp;			\
 					if( pre == rhs ) curr->next = rhs;					\
 					else pre->next = rhs;								\
@@ -154,8 +177,7 @@
  * @}
 */
 
-//======================================================================
-// function
+/* function ==========================================================*/
 static IUTEST_ATTRIBUTE_UNUSED_ int iuAlwaysZero(void) { return 0; }
 static IUTEST_ATTRIBUTE_UNUSED_ int iuAlwaysTrue(void) { return 1; }
 
