@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_c.h
  * @brief		iris unit test t@C
@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012 Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
  * 
@@ -16,20 +16,20 @@
  * @example		main.c
  * @example		sub.c
 */
-//-----------------------------------------------------------------------
-//======================================================================
-#ifndef INCG_IRIS_iutest_H_
-#define INCG_IRIS_iutest_H_
+/*----------------------------------------------------------------------
+======================================================================*/
+#ifndef INCG_IRIS_iutest_c_H_
+#define INCG_IRIS_iutest_c_H_
 
-//======================================================================
-// include
+/* include ===========================================================*/
 #include "iutest_ver_c.h"
 #include "iutest_core_c.h"
+#include "iutest_param_tests_c.h"
+#include "iutest_static_assertion_c.h"
 #include "listener/iutest_default_printer_c.h"
 #include "listener/iutest_default_xml_generator_c.h"
 
-//======================================================================
-// define
+/* define ============================================================*/
 /**
  * @defgroup	TESTDEF		eXg`
  * @brief		eXg`}N
@@ -84,8 +84,13 @@
  * @ingroup	TESTDEF
  * @brief	ׂẴeXgs
 */
-#define IUTEST_RUN_ALL_TESTS()						iuTestRun()
+#define IUTEST_RUN_ALL_TESTS()						iuUnitTest_Run()
 
+/**
+ * @ingroup TESTDEF
+ * @brief	eXg𖾎Iɓo^
+*/
+#define IUTEST_REIGSTER_TEST(testcase_, testname_)	IUTEST_C_CALL_INITIALIZATION_SECTION(IIUT_C_TEST_INITIALIZATION_SECTION_NAME(testcase_, testname_))
 
 /**
  * @defgroup	IUTEST_ASSERT_	AT[V(ASSERT)
@@ -608,29 +613,32 @@
 #  define IUTEST_INFORM_HRESULT_FAILED(hr)			IUTEST_TEST_HRESULT_FAILED(hr, IUTEST_INFORM_FAILURE)
 #endif
 
-//======================================================================
-// declare
+/* declare ===========================================================*/
 static void			iuTestInitialize(void);
 
-//======================================================================
-// function
+/* function ==========================================================*/
 /**
  * @brief	eXg̏
 */
 static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestA(int* argc, char** argv)
 {
+	iuTestEnv_LoadEnviromentVariable();
 	iuTestEnv_ParseCommandLineA(argc, argv);
 	iuTestInitialize();
 }
 #if IUTEST_C_HAS_WCHAR_T
+/**
+ * @brief	eXg̏
+*/
 static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestW(int* argc, wchar_t** argv)
 {
+	iuTestEnv_LoadEnviromentVariable();
 	iuTestEnv_ParseCommandLineW(argc, argv);
 	iuTestInitialize();
 }
 #endif
 
-//! eXg̏
+/** eXg̏ */
 #ifdef UNICODE
 #  define iuInitIrisUnitTest	iuInitIrisUnitTestW
 #else
@@ -643,15 +651,19 @@ static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestW(int* argc, wchar_t** ar
 static void			iuTestInitialize(void)
 {
 	{
-		iuTestListener* listener = iuTestListener_MakeListener(&IIUT_C_UNITTEST().def_printer
+		iuTestListener* listener = iuTestListener_MakeListener(&iuUnitTest_GetInstance()->def_printer
 			, iuTestDefaultPrinter_OnTestProgramStart
 			, iuTestDefaultPrinter_OnTestIterationStart
+			, NULL
+			, NULL
 			, iuTestDefaultPrinter_OnTestCaseStart
 			, iuTestDefaultPrinter_OnTestStart
 			, iuTestDefaultPrinter_OnTestPartResult
 			, iuTestDefaultPrinter_OnTestRecordProperty
 			, iuTestDefaultPrinter_OnTestEnd
 			, iuTestDefaultPrinter_OnTestCaseEnd
+			, NULL
+			, NULL
 			, iuTestDefaultPrinter_OnTestIterationEnd
 			, iuTestDefaultPrinter_OnTestProgramEnd
 			);
@@ -662,15 +674,19 @@ static void			iuTestInitialize(void)
 	}
 	if( iuTestEnv_IsEnableFlag(IUTESTENV_OUTPUT_XML_REPORT) )
 	{
-		iuTestListener* listener = iuTestListener_MakeListener(&IIUT_C_UNITTEST().def_xml_generator
+		iuTestListener* listener = iuTestListener_MakeListener(&iuUnitTest_GetInstance()->def_xml_generator
 			, iuTestDefaultXMLGenerator_OnTestProgramStart
 			, iuTestDefaultXMLGenerator_OnTestIterationStart
+			, NULL
+			, NULL
 			, iuTestDefaultXMLGenerator_OnTestCaseStart
 			, iuTestDefaultXMLGenerator_OnTestStart
 			, iuTestDefaultXMLGenerator_OnTestPartResult
 			, iuTestDefaultXMLGenerator_OnTestRecordProperty
 			, iuTestDefaultXMLGenerator_OnTestEnd
 			, iuTestDefaultXMLGenerator_OnTestCaseEnd
+			, NULL
+			, NULL
 			, iuTestDefaultXMLGenerator_OnTestIterationEnd
 			, iuTestDefaultXMLGenerator_OnTestProgramEnd
 			);
@@ -679,6 +695,7 @@ static void			iuTestInitialize(void)
 			iuUnitTest_AddTestListener(listener);
 		}
 	}
+	iuUnitTest_Init();
 }
 
 #endif
