@@ -2,11 +2,12 @@
 /*
  * is not available vprintf, can be replaced.
 */
-//#define IUTEST_VPRINTF
+/*#define IUTEST_VPRINTF*/
 
 /*
  * include testing framework
 */
+#define IUTEST_C_HAS_PARAM_TEST	1
 #include "../include/iutest_c.h"
 
 IUTEST_C_WORKSPACE();
@@ -18,7 +19,12 @@ int wmain(int argc, wchar_t* argv[])
 int main(int argc, char* argv[])
 #endif
 {
-	iuInitIrisUnitTest(&argc, argv);
+	IUTEST_REIGSTER_TEST(AssertionTest, Simple);
+	IUTEST_REIGSTER_TEST(SubTest1, A);
+
+//	iuUnitTest_SetVPrintfFunction(vprintf);
+
+	IUTEST_INIT(&argc, argv);
 	return IUTEST_RUN_ALL_TESTS();
 }
 
@@ -35,41 +41,60 @@ IUTEST(Test, Version)
 
 IUTEST(AssertionTest, Simple)
 {
-	int zero = 0;
+	int zero = 0, one = 1;
 	int yes=TRUE, no=FALSE;
-	IUTEST_ASSERT_TRUE(yes);
-	IUTEST_ASSERT_FALSE(no);
-	IUTEST_ASSERT_EQ(0, zero);
-	IUTEST_ASSERT_NE(0, 1);
-	IUTEST_ASSERT_LE(1, 1);
-	IUTEST_ASSERT_LT(0, 1);
-	IUTEST_ASSERT_GE(1, 1);
-	IUTEST_ASSERT_GT(1, 0);
-#ifndef IUTEST_C_NO_FLOATINGPOINT
-	{
-		float fa = 2.0f/2;
-		double da = 2.0/2;
-		IUTEST_ASSERT_FLOAT_EQ(1, fa);
-		IUTEST_ASSERT_DOUBLE_EQ(1, da);
-		IUTEST_ASSERT_NEAR(0.1, 1.0, 1.0f);
-	}
-#endif
 
 	IUTEST_EXPECT_TRUE(yes);
 	IUTEST_EXPECT_FALSE(no);
 	IUTEST_EXPECT_EQ(0, zero);
+#if 0
 	IUTEST_EXPECT_NE(0, 1);
 	IUTEST_EXPECT_LE(1, 1);
 	IUTEST_EXPECT_LT(0, 1);
 	IUTEST_EXPECT_GE(1, 1);
 	IUTEST_EXPECT_GT(1, 0);
-#ifndef IUTEST_C_NO_FLOATINGPOINT
+#else
+	IUTEST_EXPECT_NE(zero, one);
+	IUTEST_EXPECT_LE(one , one);
+	IUTEST_EXPECT_LT(zero, one);
+	IUTEST_EXPECT_GE(one , one);
+	IUTEST_EXPECT_GT(one , zero);
+#endif
+#if IUTEST_C_HAS_FLOATINGPOINT
 	{
 		float fa = 2.0f/2;
 		double da = 2.0/2;
+		double db = 1.5;
 		IUTEST_EXPECT_FLOAT_EQ(1, fa);
 		IUTEST_EXPECT_DOUBLE_EQ(1, da);
-		IUTEST_EXPECT_NEAR(0.1, 1.0, 1.0f);
+		IUTEST_EXPECT_NEAR(da, db, 1.0f);
+	}
+#endif
+
+	IUTEST_ASSERT_TRUE(yes);
+	IUTEST_ASSERT_FALSE(no);
+	IUTEST_ASSERT_EQ(0, zero);
+#if 0
+	IUTEST_ASSERT_NE(0, 1);
+	IUTEST_ASSERT_LE(1, 1);
+	IUTEST_ASSERT_LT(0, 1);
+	IUTEST_ASSERT_GE(1, 1);
+	IUTEST_ASSERT_GT(1, 0);
+#else
+	IUTEST_ASSERT_NE(zero, one);
+	IUTEST_ASSERT_LE(one , one);
+	IUTEST_ASSERT_LT(zero, one);
+	IUTEST_ASSERT_GE(one , one);
+	IUTEST_ASSERT_GT(one , zero);
+#endif
+#if IUTEST_C_HAS_FLOATINGPOINT
+	{
+		float fa = 2.0f/2;
+		double da = 2.0/2;
+		double db = 1.5;
+		IUTEST_ASSERT_FLOAT_EQ(1, fa);
+		IUTEST_ASSERT_DOUBLE_EQ(1, da);
+		IUTEST_ASSERT_NEAR(da, db, 1.0f);
 	}
 #endif
 }
@@ -78,32 +103,17 @@ IUTEST(AssertionTest, Simple)
 
 IUTEST(AssertionTest, Windows)
 {
-	IUTEST_ASSERT_HRESULT_SUCCEEDED(0);
-	IUTEST_ASSERT_HRESULT_FAILED(-1);
-
 	IUTEST_EXPECT_HRESULT_SUCCEEDED(0);
 	IUTEST_EXPECT_HRESULT_FAILED(-1);
+
+	IUTEST_ASSERT_HRESULT_SUCCEEDED(0);
+	IUTEST_ASSERT_HRESULT_FAILED(-1);
 }
 
 #endif
 
 IUTEST(AssertionTest, String)
 {
-	IUTEST_ASSERT_STREQ("test", "test");
-	IUTEST_ASSERT_STREQ(NULL, NULL);
-
-	IUTEST_ASSERT_STRNE("test", NULL);
-	IUTEST_ASSERT_STRNE(NULL, "test");
-	IUTEST_ASSERT_STRNE("test", "host");
-
-	IUTEST_ASSERT_STRCASEEQ("test", "test");
-	IUTEST_ASSERT_STRCASEEQ("test", "TeSt");
-	IUTEST_ASSERT_STRCASEEQ(NULL, NULL);
-
-	IUTEST_ASSERT_STRCASENE("test", NULL);
-	IUTEST_ASSERT_STRCASENE(NULL, "test");
-	IUTEST_ASSERT_STRCASENE("test", "host");
-
 	IUTEST_EXPECT_STREQ("test", "test");
 	IUTEST_EXPECT_STREQ(NULL, NULL);
 
@@ -118,6 +128,21 @@ IUTEST(AssertionTest, String)
 	IUTEST_EXPECT_STRCASENE("test", NULL);
 	IUTEST_EXPECT_STRCASENE(NULL, "test");
 	IUTEST_EXPECT_STRCASENE("test", "host");
+
+	IUTEST_ASSERT_STREQ("test", "test");
+	IUTEST_ASSERT_STREQ(NULL, NULL);
+
+	IUTEST_ASSERT_STRNE("test", NULL);
+	IUTEST_ASSERT_STRNE(NULL, "test");
+	IUTEST_ASSERT_STRNE("test", "host");
+
+	IUTEST_ASSERT_STRCASEEQ("test", "test");
+	IUTEST_ASSERT_STRCASEEQ("test", "TeSt");
+	IUTEST_ASSERT_STRCASEEQ(NULL, NULL);
+
+	IUTEST_ASSERT_STRCASENE("test", NULL);
+	IUTEST_ASSERT_STRCASENE(NULL, "test");
+	IUTEST_ASSERT_STRCASENE("test", "host");
 }
 
 static int s_count = 1;
@@ -125,7 +150,7 @@ static void TestF_SetUp(void)
 {
 	s_count = 0;
 }
-static const iuTestFixture TestF = { NULL, NULL, TestF_SetUp, NULL };
+static const iuTestFixture TestF = { NULL, NULL, TestF_SetUp, NULL, NULL };
 IUTEST_F(TestF, First)
 {
 	IUTEST_EXPECT_EQ(0, s_count);
@@ -144,7 +169,7 @@ IUTEST_PMZ(ParamMethodTest, EQ, TestFunction, 0, 0);
 IUTEST_PMZ(ParamMethodTest, EQ, TestFunction, 1, 1);
 IUTEST_PMZ(ParamMethodTest, EQ, TestFunction, 2, 2);
 
-static const iuTestFixture ParamMethodTestFixed = { NULL, NULL, TestF_SetUp, NULL };
+static const iuTestFixture ParamMethodTestFixed = { NULL, NULL, TestF_SetUp, NULL, NULL };
 
 IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 0, 0);
 IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 1, 1);
@@ -152,26 +177,57 @@ IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 2, 2);
 
 #endif
 
+#if IUTEST_C_HAS_PARAM_TEST
+
+IUTEST_INSTANTIATE_TEST_CASE_P(int, A, TestP, iuRange, 0, 2 );
+
+IUTEST_P(int, TestP, Test)
+{
+	const int x = param;
+	const int kMax = 10;
+	IUTEST_ASSERT_LT(x, kMax);
+	iuConsole_Output("%d\n", x);
+}
+
+IUTEST_P(int, TestP, Test2)
+{
+	const int x = param;
+	const int kMax = 10;
+	IUTEST_ASSERT_LT(x, kMax);
+	iuConsole_Output("%d\n", x);
+}
+
+#endif
+
 #ifdef SHOW_FAILURE
 
 IUTEST(ExpectFailureTest, Simple)
 {
-	int zero = 0;
+	int zero = 0, one = 1;
 	int yes=TRUE, no=FALSE;
 	IUTEST_EXPECT_TRUE(no);
 	IUTEST_EXPECT_FALSE(yes);
 	IUTEST_EXPECT_EQ(1, zero);
+#if 0
 	IUTEST_EXPECT_NE(0, 0);
-	IUTEST_EXPECT_LE(2, 1);
+	IUTEST_EXPECT_LE(1, 0);
 	IUTEST_EXPECT_LT(1, 1);
 	IUTEST_EXPECT_GE(0, 1);
 	IUTEST_EXPECT_GT(1, 1);
+#else
+	IUTEST_EXPECT_NE(zero, zero);
+	IUTEST_EXPECT_LE(one, zero);
+	IUTEST_EXPECT_LT(one, one);
+	IUTEST_EXPECT_GE(zero, one);
+	IUTEST_EXPECT_GT(one, one);
+#endif
 	{
 		float fa = 2.0f/2;
 		double da = 2.0/2;
+		double db = 1.5;
 		IUTEST_EXPECT_FLOAT_EQ(1.1f, fa);
 		IUTEST_EXPECT_DOUBLE_EQ(1.1, da);
-		IUTEST_EXPECT_NEAR(0.1, 1.0, 0.1f);
+		IUTEST_EXPECT_NEAR(da, db, 0.1f);
 	}
 }
 
