@@ -1,5 +1,5 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_fixture_tests.c
  * @brief		iutest fixture test
@@ -8,15 +8,14 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
+/*----------------------------------------------------------------------
+======================================================================*/
 
-//======================================================================
-// include
+/* include ===========================================================*/
 #include "../include/iutest_c.h"
 
 int TestFixed_x = 0;
@@ -38,17 +37,20 @@ iuTestFixture TestFixed = {
 	, NULL
 	, TestFixed_SetUp
 	, NULL
+	, NULL
 };
 
 IUTEST_F(TestFixed, Test1)
 {
 	++TestFixed_y;
-	IUTEST_ASSERT_EQ(TestFixed_y, TestFixed_x);
+	IUTEST_EXPECT_EQ(TestFixed_y, TestFixed_x);
+	IUTEST_EXPECT_NULL(iuUnitTest_GetCurrentUserData());
 }
 
 IUTEST_F(TestFixed, Test2)
 {
 	++TestFixed_y;
-	IUTEST_ASSERT_EQ(TestFixed_y, TestFixed_x);
+	IUTEST_EXPECT_EQ(TestFixed_y, TestFixed_x);
+	IUTEST_EXPECT_NULL(iuUnitTest_GetCurrentUserData());
 }
 
